dataset_scenario_ids

Function dataset_scenario_ids 

pub fn dataset_scenario_ids(
    dir: impl AsRef<Path>,
    from: &str,
) -> Result<Vec<i64>>
The distinct scenario ids of the dataset directory dir in the named from format, ascending, the introspection sibling of read_dataset_dir (and the C ABI’s pio_scenario_ids).

Errors

As read_dataset_dir.